pm4py.algo.enhancement.organizational\_mining.local\_diagnostics package
========================================================================

Submodules
----------

pm4py.algo.enhancement.organizational\_mining.local\_diagnostics.algorithm module
---------------------------------------------------------------------------------

.. automodule:: pm4py.algo.enhancement.organizational_mining.local_diagnostics.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.enhancement.organizational_mining.local_diagnostics
   :members:
   :undoc-members:
   :show-inheritance:
